@@ -17,7 +17,7 @@ void VacationMailLineEdit::setInvalidEmail(bool state)
 {
     if (state) {
         const KStatefulBrush bgBrush(KColorScheme::View, KColorScheme::NegativeBackground);
-        setStyleSheet(QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(this).color().name()));
+        setStyleSheet(QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(palette()).color().name()));
     } else {
         setStyleSheet(QString());
     }
