@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ABSTRACTSELECTEMAILLINEEDIT_H
-#define ABSTRACTSELECTEMAILLINEEDIT_H
+#pragma once
 
 #include "ksieveui_export.h"
 #include <QWidget>
@@ -26,7 +25,7 @@ public:
 
     Q_REQUIRED_RESULT bool multiSelection() const;
     void setMultiSelection(bool multiSelection);
-    virtual Q_REQUIRED_RESULT bool isValid() const = 0;
+    Q_REQUIRED_RESULT virtual bool isValid() const = 0;
 
 Q_SIGNALS:
     void valueChanged();
@@ -36,4 +35,3 @@ private:
 };
 }
 
-#endif // ABSTRACTSELECTEMAILLINEEDIT_H
